@@ -70,6 +70,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "soll[1]u[5]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "soll"),
+                                Token("CONDITION_EXPRESSION", "[1]u[5]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "Kann([1]O[5])U[904]",
                 Tree(
@@ -175,6 +190,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "kann([1]∧[5])∧[905]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "kann"),
+                                Token("CONDITION_EXPRESSION", "([1]∧[5])∧[905]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "Muss[3]U[4]Soll[5]    Kann[502]",
                 Tree(
@@ -204,6 +234,64 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "M[3]U[4]S[5]    K[502]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "M"),
+                                Token("CONDITION_EXPRESSION", "[3]U[4]"),
+                            ],
+                        ),
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "S"),
+                                Token("CONDITION_EXPRESSION", "[5]    "),
+                            ],
+                        ),
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "K"),
+                                Token("CONDITION_EXPRESSION", "[502]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
+            pytest.param(
+                "m[3]u[4]s[5]    k[502]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "m"),
+                                Token("CONDITION_EXPRESSION", "[3]u[4]"),
+                            ],
+                        ),
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "s"),
+                                Token("CONDITION_EXPRESSION", "[5]    "),
+                            ],
+                        ),
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "k"),
+                                Token("CONDITION_EXPRESSION", "[502]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "U[1]O[5]",
                 Tree(
@@ -219,6 +307,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "u[1]O[5]",  # lower case "u"
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("PREFIX_OPERATOR", "u"),
+                                Token("CONDITION_EXPRESSION", "[1]O[5]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
         ],
     )
     def test_parse_valid_ahb_expression_to_to_single_requirement_indicator_expressions(
@@ -239,7 +342,13 @@ class TestAhbExpressionParser:
             pytest.param(""),
             pytest.param("   "),
             pytest.param("[1]"),  # without requirement indicator
-            pytest.param("Mus[2]"),
+            pytest.param("Mus[2]"),  # this is a tricky one because since we introduced lower case operators and modal
+            # marks the characters alone are all ok (lower case 'u' is a valid expression operator and lower case 's'
+            # could be interpreted as lower case model mark). As of 2021-10-27, when parsing an AHB expression we only
+            # use a simple regex to roughly check if the characters at the positions where we expect condition
+            # expressions to be found are allow listed. But we do not check the grammar yet. The grammar is checked
+            # upon parsing the condition expression, but that's the second step. To keep the test failing, I introduced
+            # a negative look ahead where formerly only a "character set" allow list check.
             pytest.param("Muss[2]B[3]"),
         ],
     )
@@ -250,7 +359,7 @@ class TestAhbExpressionParser:
             parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_expression)
 
         assert """Please make sure that the ahb_expression starts with a requirement indicator \
-(i.e Muss, Soll, Kann, X, O, U) and the condition expressions consist of only \
+(i.e Muss/M, Soll/S, Kann/K, X, O, U) and the condition expressions consist of only \
 the following characters: [ ] ( ) U ∧ O ∨ X ⊻ and digits.""" in str(
             excinfo.value
         )
