@@ -9,13 +9,14 @@ import pytest
 from lark import Token, Tree
 from marshmallow import Schema, ValidationError
 
-from ahbicht.condition_check_results import (
-    ConditionCheckResult,
-    ConditionCheckResultSchema,
+from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
+from ahbicht.edifact import EdifactFormat
+from ahbicht.evaluation_results import (
+    AhbExpressionEvaluationResult,
+    AhbExpressionEvaluationResultSchema,
     FormatConstraintEvaluationResult,
     RequirementConstraintEvaluationResult,
 )
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
 from ahbicht.expressions.ahb_expression_parser import parse_ahb_expression_to_single_requirement_indicator_expressions
 from ahbicht.expressions.condition_nodes import (
     ConditionFulfilledValue,
@@ -23,6 +24,12 @@ from ahbicht.expressions.condition_nodes import (
     EvaluatedFormatConstraintSchema,
 )
 from ahbicht.json_serialization.tree_schema import TreeSchema
+from ahbicht.mapping_results import (
+    ConditionKeyConditionTextMapping,
+    ConditionKeyConditionTextMappingSchema,
+    PackageKeyConditionExpressionMapping,
+    PackageKeyConditionExpressionMappingSchema,
+)
 
 T = TypeVar("T")
 
@@ -215,10 +222,10 @@ class TestJsonSerialization:
             assert isinstance(rc_evaluation_result, ConditionFulfilledValue)
 
     @pytest.mark.parametrize(
-        "condition_check_result, expected_json_dict",
+        "ahb_expression_evaluation_result, expected_json_dict",
         [
             pytest.param(
-                ConditionCheckResult(
+                AhbExpressionEvaluationResult(
                     requirement_indicator="Muss",
                     format_constraint_evaluation_result=FormatConstraintEvaluationResult(
                         error_message="hello", format_constraints_fulfilled=False
@@ -246,7 +253,114 @@ class TestJsonSerialization:
             ),
         ],
     )
-    def test_condition_check_result_serialization(
-        self, condition_check_result: ConditionCheckResult, expected_json_dict: dict
+    def test_ahb_expression_evaluation_result_serialization(
+        self, ahb_expression_evaluation_result: AhbExpressionEvaluationResult, expected_json_dict: dict
     ):
-        _test_serialization_roundtrip(condition_check_result, ConditionCheckResultSchema(), expected_json_dict)
+        _test_serialization_roundtrip(
+            ahb_expression_evaluation_result, AhbExpressionEvaluationResultSchema(), expected_json_dict
+        )
+
+    @pytest.mark.parametrize(
+        "ahb_expression_evaluation_result, expected_json_dict",
+        [
+            pytest.param(
+                AhbExpressionEvaluationResult(
+                    requirement_indicator="Muss",
+                    format_constraint_evaluation_result=FormatConstraintEvaluationResult(
+                        error_message="hello", format_constraints_fulfilled=False
+                    ),
+                    requirement_constraint_evaluation_result=RequirementConstraintEvaluationResult(
+                        hints="foo bar",
+                        requirement_constraints_fulfilled=True,
+                        requirement_is_conditional=True,
+                        format_constraints_expression="[asd]",
+                    ),
+                ),
+                {
+                    "format_constraint_evaluation_result": {
+                        "error_message": "hello",
+                        "format_constraints_fulfilled": False,
+                    },
+                    "requirement_constraint_evaluation_result": {
+                        "format_constraints_expression": "[asd]",
+                        "hints": "foo bar",
+                        "requirement_constraints_fulfilled": True,
+                        "requirement_is_conditional": True,
+                    },
+                    "requirement_indicator": "Muss",
+                },
+            ),
+            pytest.param(
+                AhbExpressionEvaluationResult(
+                    requirement_indicator="Muss",
+                    format_constraint_evaluation_result=FormatConstraintEvaluationResult(
+                        format_constraints_fulfilled=False
+                    ),
+                    requirement_constraint_evaluation_result=RequirementConstraintEvaluationResult(
+                        requirement_constraints_fulfilled=True,
+                        requirement_is_conditional=True,
+                    ),
+                ),
+                {
+                    "format_constraint_evaluation_result": {
+                        "error_message": None,
+                        "format_constraints_fulfilled": False,
+                    },
+                    "requirement_constraint_evaluation_result": {
+                        "format_constraints_expression": None,
+                        "hints": None,
+                        "requirement_constraints_fulfilled": True,
+                        "requirement_is_conditional": True,
+                    },
+                    "requirement_indicator": "Muss",
+                },
+                id="Minimal example",
+            ),
+        ],
+    )
+    def test_ahb_expression_evaluation_result_serialization(
+        self, ahb_expression_evaluation_result: AhbExpressionEvaluationResult, expected_json_dict: dict
+    ):
+        _test_serialization_roundtrip(
+            ahb_expression_evaluation_result, AhbExpressionEvaluationResultSchema(), expected_json_dict
+        )
+
+    @pytest.mark.parametrize(
+        "condition_key_condition_text_mapping, expected_json_dict",
+        [
+            pytest.param(
+                ConditionKeyConditionTextMapping(
+                    edifact_format=EdifactFormat.UTILMD,
+                    condition_key="123",
+                    condition_text="Blablabla",
+                ),
+                {"edifact_format": "UTILMD", "condition_key": "123", "condition_text": "Blablabla"},
+            ),
+        ],
+    )
+    def test_condition_key_condition_text_mapping_serialization(
+        self, condition_key_condition_text_mapping: ConditionKeyConditionTextMapping, expected_json_dict: dict
+    ):
+        _test_serialization_roundtrip(
+            condition_key_condition_text_mapping, ConditionKeyConditionTextMappingSchema(), expected_json_dict
+        )
+
+    @pytest.mark.parametrize(
+        "package_key_condition_expression_mapping, expected_json_dict",
+        [
+            pytest.param(
+                PackageKeyConditionExpressionMapping(
+                    edifact_format=EdifactFormat.UTILMD,
+                    package_key="123P",
+                    package_expression="[1] U [2] O [3]",
+                ),
+                {"edifact_format": "UTILMD", "package_key": "123P", "package_expression": "[1] U [2] O [3]"},
+            ),
+        ],
+    )
+    def test_package_key_condition_expression_mapping_serialization(
+        self, package_key_condition_expression_mapping: PackageKeyConditionExpressionMapping, expected_json_dict: dict
+    ):
+        _test_serialization_roundtrip(
+            package_key_condition_expression_mapping, PackageKeyConditionExpressionMappingSchema(), expected_json_dict
+        )
